package org.esupportail.portal.channels.gestion.CMonDossierWeb;

import java.sql.SQLException;
import org.jasig.portal.services.LogService;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.SubChannel;
import org.esupportail.portal.utils.database.Query;

/**
 * Adresses<br>
 * <br>
 * Gestion de l'affichage des adresses d'un tudiant <br>
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:cedric.champmartin@univ-nancy2.fr">Cdric Champmartin</a>
 * @version 1.0
 * 
 */
public class Adresses extends SubChannel {
	
	//Classe principale de la channel
	private CMonDossierWeb owner;
	private String xml;
	
	/**
	 * Contructeur de la classe
	 * @param main
	 */
	public Adresses(MainChannel main) {
		super(main);
		owner = (CMonDossierWeb)main;
	}

	public Boolean setXML() throws FrameWorkException {
			
		if (xml == null) {
			xml = START_XML;
			xml += owner.getXmlEtudiant();
			xml += getXmlAdrAnnu();
			xml += getXmlAdrFixe();
			xml += END_XML;
		}
		setXML(xml);
		
		return Boolean.TRUE;
	}
	
	
	
	/**
	 * Mthode qui retourne l'adresse annuelle d'un tudiant sous forme d'un flux xml 
	 * 
	 */
	public String getXmlAdrAnnu() throws FrameWorkException {

		String res = "<adrAnnuelle>";
		Query qry = null;
		boolean error = false;
		
		if (owner.getCodInd() != null) { // la personne connecte  un cod_ind
			try {
				qry = Config.getInstance().getConnexionDefault();
				qry.setSql("select   a.lib_ad1,a.lib_ad2,a.lib_ad3,a.num_tel," +
   						   "decode(a.lib_ade,NULL,a.cod_bdi || ' - ' ||cb.lib_ach,a.lib_ade) \"VILLE\"," +
   						   "p.lib_pay \"PAYS\" " +
   						   "from apogee.adresse a,apogee.com_bdi cb,apogee.pays p " +
   						   "where cod_ind_ina = ? and cod_anu_ina = ? " +
   						   "and   cb.cod_com (+) = a.cod_com and   cb.cod_bdi (+) = a.cod_bdi " +
   						   "and   p.cod_pay = a.cod_pay");
				qry.getStmt().setString(1, owner.getCodInd());
				qry.getStmt().setString(2, Config.getInstance().getCOD_ANU_INS()); //this.COD_ANU_INS
				qry.select();			  
				String lib_ad2 = null; 
				while (qry.getRs().next()){
					lib_ad2 = (qry.getRs().getString("lib_ad2") == null) ? "" : qry.getRs().getString("lib_ad2");
					res += "<adresse1>" +qry.getRs().getString("lib_ad1")+"</adresse1>" +
							 "<adresse2>"+lib_ad2+"</adresse2>" +
							 "<ville>"+qry.getRs().getString("VILLE")+"</ville>" +
							 "<pays>"+qry.getRs().getString("PAYS")+"</pays>" + 
							 "<tel>"+qry.getRs().getString("num_tel")+"</tel>";   
				}
			}
			catch (SQLException e) {
				LogService.log(LogService.ERROR ,"Adresses::getXmlAdrAnnu() : Erreur SQL " + e);
				error = true;
			}
			finally {
				qry.close();
				if (error)
					throw new FrameWorkException();
			}
		} 
		
		res += "</adrAnnuelle>";

		return res;

	}
	
	/**
	 * Mthode qui retourne l'adresse fixe d'un tudiant sous forme d'un flux xml 
	 * 
	 */
	public String getXmlAdrFixe() throws FrameWorkException {

		String res = "<adrFixe>";
		Query qry = null;
		boolean error = false;
	
		if (owner.getCodInd() != null) { // la personne connecte  un cod_ind
			try {
				qry = Config.getInstance().getConnexionDefault();
				qry.setSql("select   a.lib_ad1,a.lib_ad2,a.lib_ad3,a.num_tel," +
   						   "decode(a.lib_ade,NULL,a.cod_bdi || ' - ' ||cb.lib_ach,a.lib_ade) \"VILLE\"," +
   						   "p.lib_pay \"PAYS\" " +
   						   "from apogee.adresse a,apogee.com_bdi cb,apogee.pays p " +
   						   "where cod_ind = ? and cb.cod_com (+) = a.cod_com " +
   						   "and   cb.cod_bdi (+) = a.cod_bdi and   p.cod_pay = a.cod_pay");
				qry.getStmt().setString(1, owner.getCodInd());
				qry.select();			   
				String lib_ad2 = null;
				while (qry.getRs().next()){
					lib_ad2 = (qry.getRs().getString("lib_ad2") == null) ? "" : qry.getRs().getString("lib_ad2");
					res += "<adresse1>" +qry.getRs().getString("lib_ad1")+"</adresse1>" +
							"<adresse2>"+lib_ad2+"</adresse2>" +
							"<ville>"+qry.getRs().getString("VILLE")+"</ville>" +
							"<pays>"+qry.getRs().getString("PAYS")+"</pays>" + 
							"<tel>"+qry.getRs().getString("num_tel")+"</tel>";   
				}
			}
			catch (SQLException e) {
				LogService.log(LogService.ERROR ,"Adresses::getXmlAdrFixe() : Erreur SQL " + e);
				error = true;
			}
			finally {
				qry.close();
				if (error)
					throw new FrameWorkException();
			}
		} 
		
		res += "</adrFixe>";

		return res;

	}
	
}
