package org.esupportail.portal.channels.gestion.CMonDossierWeb;

import java.sql.SQLException;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.connectors.ApogeeConnector;
import org.esupportail.portal.utils.connectors.ConnectorException;
import org.esupportail.portal.utils.database.Query;
import org.jasig.portal.ChannelStaticData;
import org.jasig.portal.PortalException;
import org.jasig.portal.security.IPerson;
import org.jasig.portal.services.LogService;
import org.esupportail.portal.utils.channels.plugins.FatalError;


/**
 * 
 * <p>CAdresses</p>
 * <p>Description : Modification des adresses APOGEE par les tudiants eux-mmes</p>
 * (c)Copyright <a href="www.esup-portail.org">ESup-Portail 2004</a>
 * @author <a href="mailto:olivier.ziller@univ-nancy2.fr">Olivier Ziller</a>
 * @version 1.0
 *
 */
public class CMonDossierWeb extends MainChannel {
	
	// id de l'utilisateur
	private String userId;
	// cod_ind de l'utilisateur
	private String cod_ind;
	// flux xml correspondant  l'en-tte des diffrentes pages
	private String xmlEtudiant;
	
	public CMonDossierWeb() throws PortalException {
		setConfigActions(Config.getInstance());	
	}
	
	/** 
	 *  Receive static channel data from the portal.
	 *  Satisfies implementation of IChannel Interface.
	 *
	 *  @param <b>ChannelStaticData</b> sd static channel data
	 * @throws PortalException
	 */
	public void setStaticData(ChannelStaticData sd) throws PortalException {
		super.setStaticData(sd);
		userId = (String) staticData.getPerson().getAttribute(IPerson.USERNAME);
		cod_ind = getCodInd();
	}
  
	/**
	 * @return
	 */
	public String getUserId() {
		return userId;
	}
	
	/**
	 * Rcupration du cod_ind 
	 * 
	 */
	public String getCodInd() {
		if (cod_ind == null) {
			// on rcupre le cod_ind via le connecteur Apogee
			try {
				cod_ind = ApogeeConnector.getCOD_IND(getStaticData().getPerson());
				// pour test 
				// cod_ind = "29701020"; // V. Jeannot pour VAC
			} 
			catch (ConnectorException e1) {
				// enregistrement plugin fatalError
				FatalError.fatalError(this, "Vous n'tes pas tudiant!");
				return null;
			}
		}
		return cod_ind;
	}
	
	
	/**
	 * Mthode qui retourne les infos principales d'un tudiant sous forme d'un flux xml 
	 * 
	 */
	public String getXmlEtudiant() throws FrameWorkException {
		Query qry = null;
		boolean error = false;
		
		if (xmlEtudiant == null) {
			xmlEtudiant = "<etudiant>";
			//	Connexion  la base et excution d'une requte
			try {
				// on rcupre le cod_ind via le connecteur Apogee
				cod_ind = getCodInd(); 
					
				if (cod_ind != null) { // la personne connecte  un cod_ind
					qry = Config.getInstance().getConnexionDefault();
					qry.setSql("select i.cod_etu,i.cod_nne_ind,i.cod_cle_nne_ind,i.lib_nom_pat_ind,i.lib_pr1_ind," +
									 "i.daa_ent_etb, i.cod_etb " +
									 " from apogee.individu i " +
									 " where i.cod_ind = ? ");
					qry.getStmt().setString(1, cod_ind);				
					qry.select();			   
					while (qry.getRs().next()){
						xmlEtudiant += "<dossier>" +qry.getRs().getString("cod_etu")+"</dossier>" +
								 		"<NNE>"+qry.getRs().getString("cod_nne_ind")+qry.getRs().getString("cod_cle_nne_ind")+"</NNE>" +
								 		"<nom>"+qry.getRs().getString("lib_nom_pat_ind")+"</nom>" +
								 		"<prenom>"+qry.getRs().getString("lib_pr1_ind")+"</prenom>" +
								 		"<email></email>";   // "+qry.getRs().getString("mail")+"
					}
				}
			} 
			catch (SQLException e) {
				LogService.log(LogService.ERROR ,"Adresses::getXmlEtudiant() : Erreur SQL " + e);
			}
			finally {
				qry.close();
				if (error)
					throw new FrameWorkException();
			}
			xmlEtudiant += "</etudiant>";
		}
		return xmlEtudiant;

	}
	

}
