package org.esupportail.portal.channels.gestion.CMonDossierWeb;

import java.sql.SQLException;
import org.jasig.portal.ChannelRuntimeData;
import org.jasig.portal.PortalException;
import org.jasig.portal.services.LogService;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.SubChannel;
import org.esupportail.portal.utils.database.Query;


/**
 * Etat civil<br>
 * <br>
 * Gestion de l'affichage de l'tat civil d'un tudiant <br>
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:cedric.champmartin@univ-nancy2.fr">Cdric Champmartin</a>
 * @version 1.0
 * 
 */
public class EtatCivil extends SubChannel  {

	//Rmq : Les mthodes non documentes sont hrites de la classe SubChannel, et surcharges ici
	
	// Classe principale de la channel
	private CMonDossierWeb owner;
	// nationalit
	private String nationalite;
	// date de naissance
	private String datNaiss;
	// lieu de naissance
	private String lieu;
	// dpartement
	private String depPays;
	// code du pays
	private String codPays;
	// code type dep/pays
	private String codTypDepPays;
	// code ETB
	private String codETB;
	// date de premire inscription
	private String datDebInscr;
	// flux xml : calcul qu'une seul fois, raffich ensuite
	private String xml; 
		
	/**
	 * Contructeur de la classe
	 * @param main
	 */
	public EtatCivil(MainChannel main) {
		super(main);
		owner = (CMonDossierWeb)main;
	}

	public Boolean setXML() throws FrameWorkException {
		
		if (xml == null) {
			xml = START_XML;
			xml += getXmlGeneralites();
			xml += getXmlNaissance();
			xml += getXmlInscrUniv();
			xml += getXmlBac();
			xml += END_XML;		
		}
		setXML(xml);
			
		return Boolean.TRUE;
	}
	
	public Boolean init(ChannelRuntimeData rd) throws PortalException, FrameWorkException {
		Boolean res = super.init(rd);
		return res;	
	}
	
	/**
	 * Mthode qui retourne les inscriptions d'un tudiant sous forme d'un flux xml 
	 * 
	 */
	public String getXmlGeneralites() throws FrameWorkException {
		
		String res = "<generalites>";
		Query qry = null;
		boolean error = false;
		
		if (owner.getCodInd() != null) { // la personne connecte  un cod_ind
			try {
				qry = Config.getInstance().getConnexionDefault();
				// qry = new Query((Database) connexions.get("Apogee1"));
				qry.setSql("select i.cod_etu,i.cod_nne_ind,i.cod_cle_nne_ind,i.lib_nom_pat_ind,i.lib_pr1_ind, "+
						   "to_char(i.date_nai_ind,'DD/MM/YYYY') \"DATE_NAI_IND\", i.lib_vil_nai_etu, "+
							"i.cod_dep_pay_nai, i.daa_ent_etb, i.cod_typ_dep_pay_nai, i.cod_pay_nat, i.cod_etb "+ 
				 			"from apogee.individu i " + 
				 			"where i.cod_ind = ? "); //  23001316
				qry.getStmt().setString(1, owner.getCodInd());				
				qry.select();			   
				while (qry.getRs().next()){
					res += "<dossier>" +qry.getRs().getString("cod_etu")+"</dossier>" +
						   "<NNE>"+qry.getRs().getString("cod_nne_ind")+qry.getRs().getString("cod_cle_nne_ind")+"</NNE>" +
						   "<nom>"+qry.getRs().getString("lib_nom_pat_ind")+"</nom>" +
						   "<prenom>"+qry.getRs().getString("lib_pr1_ind")+"</prenom>" +
						   "<email></email>"; // "+qry.getRs().getString("mail")+"
					this.codPays = qry.getRs().getString("cod_pay_nat");
					this.datNaiss = qry.getRs().getString("date_nai_ind");
					this.lieu = qry.getRs().getString("lib_vil_nai_etu");
					this.depPays = qry.getRs().getString("cod_dep_pay_nai"); 
					this.codTypDepPays = qry.getRs().getString("cod_typ_dep_pay_nai");
					this.datDebInscr = qry.getRs().getString("daa_ent_etb");
					this.codETB = qry.getRs().getString("cod_etb");
						   
				}
			}
			catch (SQLException e) {
				LogService.log(LogService.ERROR ,"EtatCivil::getXmlGeneralites() : Erreur SQL " + e);
				error = true;
				throw new FrameWorkException();
			}
			finally {
				qry.close();
				if (error)
					throw new FrameWorkException();
			}
		} 
		res += "</generalites>";
		
		return res;
		
	}
	
	
	public String getXmlNaissance() throws FrameWorkException {
		String res = "<naissance>";
		Query qry = null;
		boolean error = false;
		
		try {
			qry = Config.getInstance().getConnexionDefault();
			//nationalit
			qry.setSql("select LIB_NAT from apogee.pays where cod_pay = ?");
			qry.getStmt().setString(1, this.codPays);				
			qry.select();
			while (qry.getRs().next()){
				res += "<nationalite>"+qry.getRs().getString("lib_nat")+"</nationalite>";				
			}
			// Recherche Pays ou Dpartement de Naissance
	  	    if (this.codTypDepPays.equals("D"))  
				qry.setSql("select LIB_DEP \"LIB_DEP_PAY\" from apogee.departement where cod_dep = ?");
	  	    else 
				qry.setSql("select LIB_PAY \"LIB_DEP_PAY\" from apogee.pays where cod_pay = ?");
	  	    qry.getStmt().setString(1, this.depPays);
			qry.select();
			while (qry.getRs().next()){
				res += "<depPays>"+qry.getRs().getString("lib_dep_pay")+"</depPays>";				
			} 
		} 
		catch (SQLException e) {
			LogService.log(LogService.ERROR ,"EtatCivil::getXmlNaissance() : Erreur SQL " + e);
			error = true;
		}
		finally {
			qry.close();
			if (error)
				throw new FrameWorkException();
		}					
		res += "<datNaiss>"+this.datNaiss+"</datNaiss>";
		res += "<lieu>"+this.lieu+"</lieu>";
		res += "</naissance>";
		
		return res;
	}	
	
	public String getXmlInscrUniv() throws FrameWorkException {
		String res = "<inscrUniv>";
		Query qry = null;
		boolean error = false;
		
		try {
			qry = Config.getInstance().getConnexionDefault();
			qry.setSql("select LIB_ETB from apogee.etablissement where cod_etb = ?");
			qry.getStmt().setString(1, this.codETB);				
			qry.select();
			while (qry.getRs().next()){
				res += "<etablissement>"+qry.getRs().getString("lib_etb")+"</etablissement>";				
			}
		} 
		catch (SQLException e) {
			LogService.log(LogService.ERROR ,"EtatCivil::getXmlInscrUniv() : Erreur SQL " + e);
			error = true;
		}
		finally {
			qry.close();
			if (error)
				throw new FrameWorkException();
		}					
		res += "<annee>"+this.datDebInscr+ "</annee>";
		res += "</inscrUniv>";
		
		return res;
	}	
		
	public String getXmlBac() throws FrameWorkException {
		String cod_mnb;
		String cod_tpe;
		String cod_etb;
		String res = "<bacs>";
		Query qry = null;
		boolean error = false;
		
		try {
			qry = Config.getInstance().getConnexionDefault();
			qry.setSql("select b.lib_bac,ib.daa_obt_bac_iba,ib.cod_mnb,ib.cod_tpe,ib.cod_etb ,ib.cod_dep "+ 
					   "from apogee.bac_oux_equ b, apogee.ind_bac ib "+
					   "where ib.cod_ind = ? and b.cod_bac = ib.cod_bac ");
			LogService.log(LogService.INFO ,"EtatCivil::getXmlBac() :cod_ind " + owner.getCodInd());   
			qry.getStmt().setString(1,owner.getCodInd());				
			qry.select();
			Query qry1 = null;
			while (qry.getRs().next()){
				// initialisation
				cod_mnb = "";
				cod_tpe = "";
				cod_etb = "";
				cod_mnb = qry.getRs().getString("cod_mnb");
				cod_tpe = qry.getRs().getString("cod_tpe");
				cod_etb = qry.getRs().getString("cod_etb");
				
				res += "<bac>";
				// type
				res += "<type>" +qry.getRs().getString("lib_bac")+ "</type>";
				// date obtention
				res += "<datObtention>" +qry.getRs().getString("daa_obt_bac_iba")+ "</datObtention>";
				// dpartement
				res += "<departement>"+qry.getRs().getString("cod_dep")+"</departement>";
				try {
					qry1 = Config.getInstance().getConnexionDefault();
					// mention
					qry1.setSql("select lib_men from apogee.mention where cod_men = ?");
					qry1.getStmt().setString(1, cod_mnb);
					qry1.select();
					while (qry1.getRs().next()) {
						res += "<mention>"+qry1.getRs().getString("lib_men")+ "</mention>";
					}
					// type etablissement
					qry1.setSql("select lib_tpe from apogee.typ_etb where cod_tpe = ?");
					qry1.getStmt().setString(1, cod_tpe);
					qry1.select();
					while (qry1.getRs().next()) {
						res += "<typEtabliss>"+qry1.getRs().getString("lib_tpe")+ "</typEtabliss>";
					}
					// Type Etablissement Bac
					qry1.setSql("select lib_etb from apogee.etablissement "+
		   						"where cod_tpe = ? and cod_etb = ? ");
					qry1.getStmt().setString(1, cod_tpe);
					qry1.getStmt().setString(2, cod_etb);
					qry1.select();
					while (qry1.getRs().next()) {
						res += "<etablissement>"+qry1.getRs().getString("lib_etb")+ "</etablissement>";
					}	
				}
				finally {
					qry1.close();
				}
				
				res += "</bac>";				
			}
		} 
		catch (SQLException e) {
			LogService.log(LogService.ERROR ,"EtatCivil::getXmlBac() : Erreur SQL " + e);
			error = true;
			
		}
		finally {
			qry.close();
			if (error)
				throw new FrameWorkException();
		}				
		res += "</bacs>";
		
		return res;
	}		
	
}	
